@@ -1,5 +1,6 @@
 import argparse
 import os
+import logging
 import pprint
 import sys
 
@@ -7,14 +8,17 @@ from simple_ddl_parser import parse_from_file
 from simple_ddl_parser.output.common import output_modes
 
 
-def cli():
-    sdb_cli = argparse.ArgumentParser(description="Simple DDL Parser")
+logger = logging.getLogger('simple_ddl_parser')
 
-    sdb_cli.add_argument(
+
+def cli():
+    sdp_cli = argparse.ArgumentParser(description="Simple DDL Parser")
+
+    sdp_cli.add_argument(
         "ddl_file_path", type=str, help="The path to ddl file to parse"
     )
 
-    sdb_cli.add_argument(
+    sdp_cli.add_argument(
         "-t",
         "--target",
         type=str,
@@ -22,25 +26,25 @@ def cli():
         help="Target path to save parse results in .json files",
     )
 
-    sdb_cli.add_argument("-v", action="store_true", default=False, help="Verbose mode")
+    sdp_cli.add_argument("-v", action="store_true", default=False, help="Verbose mode")
 
-    sdb_cli.add_argument(
+    sdp_cli.add_argument(
         "--no-dump",
         action="store_true",
         default=False,
         help="Parse without saving to the file. Only print result to the console.",
     )
-    sdb_cli.add_argument(
+    sdp_cli.add_argument(
         "-o",
         "--output-mode",
         default="sql",
         help=f"Output mode that will be used to format result. Possible variants: {output_modes}",
     )
-    return sdb_cli
+    return sdp_cli
 
 
 def run_for_file(args):
-    print(f"Start parsing file {args.ddl_file_path} \n")
+    logger.info(f"Start parsing file {args.ddl_file_path} \n")
     result = parse_from_file(
         args.ddl_file_path,
         dump=not args.no_dump,
@@ -48,7 +52,7 @@ def run_for_file(args):
         output_mode=args.output_mode,
     )
 
-    print(f"File with result was saved to >> {args.target} folder")
+    logger.info(f"File with result was saved to >> {args.target} folder")
 
     if args.v or args.no_dump:
         pprint.pprint(result)
@@ -65,11 +69,11 @@ def correct_extension(file_name: str) -> bool:
 
 
 def main():
-    sdb_cli = cli()
-    args = sdb_cli.parse_args()
+    sdp_cli = cli()
+    args = sdp_cli.parse_args()
     type(args)
     if not os.path.exists(args.ddl_file_path):
-        print("The file path specified does not exist")
+        logger.error("The file path specified does not exist")
         sys.exit()
     if os.path.isfile(args.ddl_file_path):
         run_for_file(args)
